const assert = require('assert');
const { readCSV, readJSON } = require('../index');

const data = JSON.stringify([
  { name: 'Milan Wikarski', age: '19', gender: 'M' },
  { name: 'John Smith', age: '18', gender: 'M' },
  { name: 'Summer Smith', age: '17', gender: 'F' }
]);

describe('readJSON', function() {
  it('should be able to read .json file', async function() {
    assert.equal(
      JSON.stringify(await readJSON(__dirname + '/files/data.json')),
      data
    );
  });
});

describe('readCSV', function() {
  it('should be able to read .csv file with header', async function() {
    assert.equal(
      JSON.stringify(await readCSV(__dirname + '/files/with-header.csv')),
      data
    );
  });

  it('should be able to read .csv file without header', async function() {
    assert.equal(
      JSON.stringify(
        await readCSV(__dirname + '/files/no-header.csv', ',', [
          'name',
          'age',
          'gender'
        ])
      ),
      data
    );
  });

  it('should be able to read .csv file with different separator', async function() {
    assert.equal(
      JSON.stringify(
        await readCSV(__dirname + '/files/exotic-separator.csv', '|||')
      ),
      data
    );
  });
});
